localCIDER
==========

localCIDER is the Python backend for CIDER

For more information please 
[see the documentation](http://pappulab.github.io/localCIDER/).

localCIDER was written by Alex Holehouse and James Ahad in the [Pappu Lab](http://pappulab.wustl.edu/).

Please address all questions to [Alex](http://pappulab.wustl.edu/people.html#grads). 